@@ -1,8 +1,11 @@
 
+from __future__ import annotations
 import typing as t
+import typing_extensions as te
+
 from nr.util.generic import T
 
-_Message = str | t.Callable[[], str]
+_Message: te.TypeAlias = 'str | t.Callable[[], str]'
 
 
 def _get_message(message: _Message) -> str:
